import os
from flask import Flask
from .text import joke # noqa


def create_app():
    app = Flask(__name__)
    app.config['DEBUG'] = True
    app.config['SECRET_KEY'] = 'ejkfhbwi242ri'
    app.config['BASEDIR'] = os.path.abspath(os.path.dirname(__file__))

    @app.route('/')
    def index():
        return "What's up!"

    return app



from setuptools import setup

setup(
    name='Crabsnack',
    version='0.1.1',

    classifiers=[
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
    ],

    description='The best sea food in the world',
    include_package_data=True,
    url='http://github.com/victorziv/crabsnack',
    author='Eugene H. Krabs',
    author_email='mrkrabs@bottom.com',
    license='MIT',
    packages=['crabsnack'],
    zip_safe=False,
    install_requires=[
        'markdown',
    ]
)
